Signature class

Constructors

Signature({required bool subscriptionAlreadyPurchased, required List<PurchasedSubscription> purchasedSubscriptions, required bool freeTrialConsumed, required bool allowRenewal, required bool internalUser, required Payload payload, required String consumptionId, required String signature, required bool downloadExists})
Signature.fromJson(Map<String, dynamic> json)
factory

Properties

allowRenewal ↔ bool
getter/setter pair
consumptionId ↔ String
getter/setter pair
downloadExists ↔ bool
getter/setter pair
freeTrialConsumed ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalUser ↔ bool
getter/setter pair
payload ↔ Payload
getter/setter pair
purchasedSubscriptions ↔ List<PurchasedSubscription>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ String
getter/setter pair
subscriptionAlreadyPurchased ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited