Payload class

Constructors

Payload({required String clientId, required String contentId, required String subscriptionId, required DateTime createdAt})
Payload.fromJson(Map<String, dynamic> json)
factory

Properties

clientId ↔ String
getter/setter pair
contentId ↔ String
getter/setter pair
createdAt ↔ DateTime
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited