Subscription class

Constructors

Subscription({required String tierId, required bool digital, required bool physical, required bool adFree, required String title, required bool renew, required int duration, required String durationText})
Subscription.fromJson(Map<String, dynamic> json)
factory

Properties

adFree ↔ bool
getter/setter pair
digital ↔ bool
getter/setter pair
duration ↔ int
getter/setter pair
durationText ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
physical ↔ bool
getter/setter pair
renew ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tierId ↔ String
getter/setter pair
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited